@@ -120,7 +120,7 @@ SKIP: {
             my ($infd, $outfd, $errfd);
             my ($out, $err);
             my ($pid, $rc);
-            my @args = ("globus-url-copy",
+            my @args = ("globus-url-copy-noinst",
                 @{$mode}, @{$cc}, @{$dc_opt},
                 "-cd", "-r", $src_url, $dst_url);
             $errfd = gensym;
